@@ -2,9 +2,8 @@ from . import autosimilarity_computation
 from . import barwise_input
 from . import data_manipulation
 from . import CBM_algorithm
-#from . import foote_novelty
 
-from .model import current_plot
+from .model import common_plot
+from .model import dataloaders
 from .model import errors
 from .model import signal_to_spectrogram
-from .model import display_results
